% Bias of Beta (based on MLE)

% In HN notation
% B = - H^{1} b
% H = - \mean_{i,t} U_{it} U_{it}'
% b = - (1/2) \mean_{i} \sum_{t} U_{it} V2_{it} / \sum_{s} v_{is}^{2}
% U_{it} = u_{it} - v_{it} \sum_{s} u_{is} v_{is} / \sum_{s} v_{is}^{2}
% V2_{it} = v_{it}^{2} + v_{it,a} 

function BIAS = bias_beta_probit_mle(y,x,d,n,index)

D = dummyvar(index);
t = mean(sum(D));
p = size(x,2)-n;

dy = real(y > 0);
h = d(1,1);
delta = d(2:size(d,1),1);
mu = x*delta;
lambdabar = mills_prob(-mu);

vit   = dy .* (h*y - mu) - (1 - dy) .* lambdabar ;
vita  = -dy + (1 - dy) .* dmills_prob(-mu);
vitaa = - (1 - dy) .* ddmills_prob(- mu);

uit   = [dy .* (1/h - (h*y - mu) .* y) ,  x(:,1:p) .* (vit*ones(1,p))];
uita  = [dy .* y,   x(:,1:p) .* (vita*ones(1,p))];
uitaa = [0*y,  x(:,1:p) .* (vitaa*ones(1,p))];

vitb  = uita;
s_vita = kron(D'*vita,ones(t,1));
s_vitb = kron(D'*vitb,ones(t,1));

U = uit - (vit*ones(1,p+1)) .* kron((D'*(uit .* (vit*ones(1,p+1)))) ./ (D'*((vit*ones(1,p+1)) .^2 )),ones(t,1));

H =  - (1/t) * U'*U;

pit   = phi_alpha_tobit_mle(y,x,d,index);

vis = reshape(vit,t,n);
vis = [zeros(1,n) ; vis(1:(t-1),:)];
vis = (t/(t-1))*reshape(vis,t*n,1);

uisa = reshape(uita,t,n*(p+1));
uisa = [zeros(1,n*(p+1)) ; uisa(1:(t-1),:)];
uisa = (t/(t-1))*reshape(uisa,t*n,p+1);

Uit = uit - (s_vitb ./ (s_vita * ones(1,p+1))) .* (vit * ones(1,p+1));
Uita = uita - (s_vitb ./ (s_vita * ones(1,p+1))) .* (vita * ones(1,p+1));
Uitaa = uitaa - (s_vitb ./ (s_vita * ones(1,p+1))) .* (vitaa * ones(1,p+1));

fVUia = (1/t) * D' * ((vit*ones(1,p+1)).*(uita + uisa) + (vis*ones(1,p+1)).*uita);
fVVi = (1/t) * D' * (vit.^2 + 2*vit.*vis) * ones(1,p+1);

s_vita = (1/t) * D' * vita * ones(1,p+1);
s_Uitaa = (1/t) * D' * Uitaa;

b = - sum(fVUia ./ s_vita - (1/2) * (s_Uitaa .* fVVi) ./ (s_vita.^2),1)';

BIAS  = - inv(H)*b;
